Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1081)

Unified Diff: third_party/WebKit/Source/web/WebViewFrameWidget.h

Issue 2850113002: Move WebViewFrameWidget to use WebViewBase rather than WebViewImpl. (Closed)
Patch Set: Fix code review comments. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebViewFrameWidget.h
diff --git a/third_party/WebKit/Source/web/WebViewFrameWidget.h b/third_party/WebKit/Source/web/WebViewFrameWidget.h
index c891504b5c1808b27e9699cd07e17842f5ea81e4..78f16c90c4e72bef29f1a732170b2e96ff403a5c 100644
--- a/third_party/WebKit/Source/web/WebViewFrameWidget.h
+++ b/third_party/WebKit/Source/web/WebViewFrameWidget.h
@@ -14,7 +14,7 @@
namespace blink {
-class WebViewImpl;
+class WebViewBase;
class WebWidgetClient;
// Shim class to help normalize the widget interfaces in the Blink public API.
@@ -28,7 +28,7 @@ class WebWidgetClient;
// and just forwards almost everything to it.
// After the embedder starts using a WebFrameWidget for the main frame,
// WebView will be updated to no longer inherit WebWidget. The eventual goal is
// to unfork the widget code duplicated in WebFrameWidgetImpl and WebViewImpl
// into one class.
// A more detailed writeup of this transition can be read at
// https://goo.gl/7yVrnb.
@@ -37,7 +37,7 @@ class WebViewFrameWidget : public WebFrameWidgetBase {
public:
explicit WebViewFrameWidget(WebWidgetClient&,
- WebViewImpl&,
+ WebViewBase&,
WebLocalFrameImpl&);
virtual ~WebViewFrameWidget();
@@ -109,7 +109,7 @@ class WebViewFrameWidget : public WebFrameWidgetBase {
private:
WebWidgetClient* client_;
- RefPtr<WebViewImpl> web_view_;
+ RefPtr<WebViewBase> web_view_;
Persistent<WebLocalFrameImpl> main_frame_;
};
« no previous file with comments | « third_party/WebKit/Source/core/exported/WebViewBase.h ('k') | third_party/WebKit/Source/web/WebViewFrameWidget.cpp » ('j') | no next file with comments »
@@ -28,7 +28,7 @@ class WebWidgetClient;
// After the embedder starts using a WebFrameWidget for the main frame,
// WebView will be updated to no longer inherit WebWidget. The eventual goal is
-// to unfork the widget code duplicated in WebFrameWidgetImpl and WebViewImpl
+// to unfork the widget code duplicated in WebFrameWidgetImpl and WebViewBase
// into one class.
// A more detailed writeup of this transition can be read at

Powered by Google App Engine
This is Rietveld 408576698